.. _glossary:

Glossary
========

.. glossary::

   wakati gaki
      wakati gaki is a way to express words with space character.
      ordinary japanese text does not use space for separating words,
      instead reader understand heulisticly.

   Romaji
      alphabetical description of Japanese pronunciation.
